@@ -11,9 +11,6 @@ from asyncactor import Actor
 from asyncactor.backend import get_transport
 from asyncactor import PingEvent, TagEvent
 
-import logging
-
-logger = logging.getLogger(__name__)
 
 TAGS = 4
 
