@@ -5,8 +5,17 @@ import attr
 import socket
 
 from distkv.client import open_client
-from distkv.command import main
 from distkv.default import CFG
+from distkv.util import attrdict, list_ext, load_ext, combine_dict, wrap_main
+
+CFG = attrdict(**CFG)  # shallow copy
+for n, _ in list_ext("distkv_ext"):
+    try:
+        CFG[n] = combine_dict(
+            load_ext("distkv_ext", n, "config", "CFG"), CFG.get(n, {}), cls=attrdict
+        )
+    except ModuleNotFoundError:
+        pass
 
 try:
     from contextlib import asynccontextmanager
@@ -20,7 +29,9 @@ async def run(*args, expect_exit=0, do_stdout=True):
         CFG["_stdout"] = out = io.StringIO()
     try:
         print("*****", args)
-        res = await main.main(args)
+        res = await wrap_main(args=args, wrap=True, CFG=CFG, cfg=False)
+        if res is None:
+            res = attrdict()
         return res
     except SystemExit as exc:
         res = exc
@@ -42,7 +53,6 @@ async def run(*args, expect_exit=0, do_stdout=True):
 class S:
     tg = attr.ib()
     client_ctx = attr.ib()
-    serfs = attr.ib(factory=set)
     s = attr.ib(factory=list)  # servers
     c = attr.ib(factory=list)  # clients
     _seq = 1
@@ -68,10 +78,10 @@ class S:
             if host[0] == ":":
                 continue
             try:
-                async with open_client(
-                    _main_name="_client_%d_%d" % (i, self._seq),
-                    connect=dict(host=host, port=port, ssl=self.client_ctx, **kv),
-                ) as c:
+                cfg = combine_dict(
+                    dict(connect=dict(host=host, port=port, ssl=self.client_ctx, **kv)), CFG
+                )
+                async with open_client(_main_name="_client_%d_%d" % (i, self._seq), **cfg) as c:
                     yield c
                     return
             except socket.gaierror:
