@@ -1,13 +1,8 @@
 # command line interface helpers for objects
 
-import os
-import sys
-
 import asyncclick as click
 
-from distkv.util import P, attrdict
-from distkv.data import data_get
-from distkv_ext.inv.model import InventoryRoot, Host, Wire
+from distkv.util import NotGiven
 
 import logging
 
@@ -15,6 +10,7 @@ logger = logging.getLogger(__name__)
 
 __all__ = ["inv_sub"]
 
+
 class _InvSub:
     """
     This class is a helper for "inv_sub".
@@ -23,15 +19,16 @@ class _InvSub:
     def __init__(
         self,
         name,
-        id_name=None,
-        id_typ=None,
+        id_name="name",
+        id_typ=str,
         aux=(),
         name_cb=None,
         id_cb=None,
         postproc=None,
-        ext=(),
         apply=None,
         short_help=None,
+        sub_base=None,
+        sub_name=None,
     ):
         self.name = name
         self.id_name = id_name
@@ -40,9 +37,13 @@ class _InvSub:
         self.apply = apply or (lambda _c, _x: None)
         self.name_cb = name_cb or (lambda _c, _k, x: x)
         self.aux = aux
-        self.ext = ext
         self.short_help = short_help
         self.postproc = postproc or (lambda _c, x: None)
+        self.sub_base = sub_base
+        if sub_name is NotGiven:
+            self.sub_name = None
+        else:
+            self.sub_name = sub_name or name
 
     def id_arg(self, proc):
         if self.id_name is None:
@@ -77,26 +78,21 @@ def inv_sub(cli, *a, **kw):
                 click.option("-w", "--wlan", type=str, default=None, help="WLAN SSID"),
             ),
             short_help="Manage VLANs",
-            ext=(test_cmd, {"name":"test", short_help="a command attached to this"})
         )
-
-    Warning: in the interest of simplifying your code, `inv_sub` modifies
-    the caller's global directory so that "test_cmd" (in this case) is now
-    a click.command (or click.group if you set group=True in the dict)
-    that's attached to the calling interface. The dict is passed as keyword
-    args to click.command/group.
-
-    Thus you can't use non-global functions in ``ext`` and you can't
-    recycle them. If you need to do that, factor the work out.
-
     """
     tinv = _InvSub(*a, **kw)
     tname = tinv.name
-    tnname = "n_"+tname
+    tnname = "n_" + tname
 
     def this(obj):
         # Delayed resolving of the actual thing subhierarchy
-        return getattr(obj.data, tname)
+        if tinv.sub_base:
+            data = getattr(obj, tinv.sub_base)
+        else:
+            data = obj.data
+        if tinv.sub_name:
+            return getattr(data, tinv.sub_name)
+        return data
 
     @cli.group(
         name=tname,
@@ -126,15 +122,12 @@ def inv_sub(cli, *a, **kw):
             n = this(obj).by_name(name)
             if n is None:
                 raise KeyError(name)
-            res = {}
             for k in n.ATTRS + getattr(n, "AUX_ATTRS", ()):
                 v = getattr(n, k, None)
                 if v is not None:
                     if isinstance(v, dict):
                         v = v.items()
-                    if isinstance(
-                        v, type({}.items())
-                    ):  # pylint: disable=isinstance-second-argument-not-valid-type
+                    if isinstance(v, type({}.items())):  # pylint: disable=W1116
                         for kk, vv in sorted(v):
                             if isinstance(vv, (tuple, list)):
                                 if vv:
@@ -169,9 +162,8 @@ def inv_sub(cli, *a, **kw):
             n = alloc(obj, kw.pop(tinv.id_name))
         else:
             n = alloc(obj, name)
-        tinv.postproc(obj, kw)
 
-        await _v_mod(n, **kw)
+        await _v_mod(obj, n, **kw)
 
     add.__doc__ = (
         """
@@ -188,9 +180,8 @@ def inv_sub(cli, *a, **kw):
         n = this(obj).by_name(name)
         if n is None:
             raise KeyError(n)
-        tinv.postproc(obj, kw)
 
-        await _v_mod(n, **kw)
+        await _v_mod(obj, n, **kw)
 
     set_.__doc__ = (
         """
@@ -205,7 +196,7 @@ def inv_sub(cli, *a, **kw):
         name = obj[tnname]
         n = this(obj).by_name(name)
         if n is not None:
-            await n.delete()
+            await n.delete(recursive=True)
 
     delete.__doc__ = (
         """
@@ -214,28 +205,19 @@ def inv_sub(cli, *a, **kw):
         % tname
     )
 
-    async def _v_mod(obj, **kw):
-        tinv.apply(obj, kw)
+    async def _v_mod(obj, thing, **kw):
+        tinv.apply(thing, kw)
         for k, v in kw.items():
             if v:
                 if v == "-":
                     v = None
                 try:
-                    setattr(obj, k, v)
+                    setattr(thing, k, v)
                 except AttributeError:
                     if k != "name":
                         raise AttributeError(k, v) from None
+        tinv.postproc(obj, thing, kw)
         await obj.save()
 
-    # Yes this is a hack.
-    import inspect
-    g = inspect.currentframe().f_back.f_globals
-    for t, kv in tinv.ext:
-        p = t
-        if kv.pop("group", False):
-            p = typ.group(**kv)(p)
-        else:
-            p = typ.command(**kv)(p)
-        g[t.__name__] = p
-
-
+    # Finally, return the CLI so the user can attach more stuff
+    return typ
