@@ -11,11 +11,7 @@ from asyncactor import PingEvent, TagEvent, UntagEvent, AuthPingEvent
 import psutil
 import time
 from collections.abc import Mapping
-
-try:
-    from contextlib import AsyncExitStack
-except ImportError:
-    from async_exit_stack import AsyncExitStack
+from contextlib import AsyncExitStack
 
 from .actor import ClientActor
 from .actor import DetachedState, PartialState, CompleteState, ActorState, BrokenState
@@ -624,8 +620,7 @@ class RunnerEntry(AttrClientEntry):
         await self.root.trigger_rescan()
 
     async def run_at(self, t: float):
-        """Next run at this time.
-        """
+        """Next run at this time."""
         self.target = t
         if not self._running:
             await self.save()
@@ -781,7 +776,8 @@ class StateEntry(AttrClientEntry):
             return
 
         # side effect: add to the global node list
-        run.root.get_node(n)
+        if n is not None:
+            run.root.get_node(n)
 
         # Check whether running code needs to be killed off
         if run.scope is None:
